aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--skate/cmd/skate-reduce/main.go62
1 files changed, 31 insertions, 31 deletions
diff --git a/skate/cmd/skate-reduce/main.go b/skate/cmd/skate-reduce/main.go
index eb84e38..be2d46e 100644
--- a/skate/cmd/skate-reduce/main.go
+++ b/skate/cmd/skate-reduce/main.go
@@ -5,35 +5,35 @@
// Support various "modes", e.g. exact, verify, ref, bref, wiki. Each mode may
// work on one or two files, and may need extra args.
//
// * exact | takes two (key, doc) TSV files (one for releases, one for refs) and
// | will emit biblioref docs relating *one* element from releases with *all*
// | elements from ref; this is for "doi", "pmid" and other id matches, where no
// | further checks are necessary. The match reason, e.g. "doi" needs to be
// | supplied.
// |
// | $ skate-reduce -m exact -r doi -F a.tsv -L b.tsv
// |
// |
// * verify | takes two (key, doc) TSV files (one for release, one for refs),
// | runs verification within a group and will emit biblioref.
// |
// | $ skate-reduce -m verify -F a.tsv -L b.tsv
// |
// |
// * ref | takes a single file with clusters containing releases and refs and
// | will emit verification results.
// |
// | $ skate-reduce -m ref < a.ndj
// |
// |
// * bref | same as ref, but generate a biblioref file as output
// |
// | $ skate-reduce -m bref < a.ndj
// |
// |
// * wiki | zippy mode for releases and wikipedia inputs.
// |
// | $ skate-reduce -m wiki -L a.ndj -W b.ndj
//
package main
@@ -53,7 +53,7 @@ import (
var (
numWorkers = flag.Int("w", runtime.NumCPU(), "number of workers")
batchSize = flag.Int("b", 10000, "batch size")
- mode = flag.String("m", "ref", "mode, e.g. exact, verify, ref, bref, wiki")
+ mode = flag.String("m", "ref", "mode, e.g. exact, fuzzy, ref, bref, wiki")
quite = flag.Bool("q", false, "be quite")
logFile = flag.String("log", "", "log filename")
@@ -101,7 +101,7 @@ func main() {
if err := skate.ZippyExact(l, f, r, bw); err != nil {
log.Fatal(err)
}
- case "verify":
+ case "fuzzy":
l, f, err := xio.OpenTwo(*releases, *refs)
if err != nil {
log.Fatal(err)
@@ -5,35 +5,35 @@
// work on one or two files, and may need extra args.
//
-// * exact | takes two (key, doc) TSV files (one for releases, one for refs) and
-// | will emit biblioref docs relating *one* element from releases with *all*
-// | elements from ref; this is for "doi", "pmid" and other id matches, where no
-// | further checks are necessary. The match reason, e.g. "doi" needs to be
-// | supplied.
-// |
-// | $ skate-reduce -m exact -r doi -F a.tsv -L b.tsv
-// |
-// |
-// * verify | takes two (key, doc) TSV files (one for release, one for refs),
-// | runs verification within a group and will emit biblioref.
-// |
-// | $ skate-reduce -m verify -F a.tsv -L b.tsv
-// |
-// |
-// * ref | takes a single file with clusters containing releases and refs and
-// | will emit verification results.
-// |
-// | $ skate-reduce -m ref < a.ndj
-// |
-// |
-// * bref | same as ref, but generate a biblioref file as output
-// |
-// | $ skate-reduce -m bref < a.ndj
-// |
-// |
-// * wiki | zippy mode for releases and wikipedia inputs.
-// |
-// | $ skate-reduce -m wiki -L a.ndj -W b.ndj
+// * exact | takes two (key, doc) TSV files (one for releases, one for refs) and
+// | will emit biblioref docs relating *one* element from releases with *all*
+// | elements from ref; this is for "doi", "pmid" and other id matches, where no
+// | further checks are necessary. The match reason, e.g. "doi" needs to be
+// | supplied.
+// |
+// | $ skate-reduce -m exact -r doi -F a.tsv -L b.tsv
+// |
+// |
+// * fuzzy | takes two (key, doc) TSV files (one for release, one for refs),
+// | runs verification within a group and will emit biblioref.
+// |
+// | $ skate-reduce -m verify -F a.tsv -L b.tsv
+// |
+// |
+// * ref | takes a single file with clusters containing releases and refs and
+// | will emit verification results.
+// |
+// | $ skate-reduce -m ref < a.ndj
+// |
+// |
+// * bref | same as ref, but generate a biblioref file as output
+// |
+// | $ skate-reduce -m bref < a.ndj
+// |
+// |
+// * wiki | zippy mode for releases and wikipedia inputs.
+// |
+// | $ skate-reduce -m wiki -L a.ndj -W b.ndj
//
package main